import PropTypes from 'prop-types';
import { useEffect } from 'react';
import invariant from 'tiny-invariant';
import useLatest from 'use-latest';

var useBeforeunload = function useBeforeunload(handler) {
  !(handler == null || typeof handler === 'function') ? process.env.NODE_ENV !== "production" ? invariant(false, 'Expected `handler` to be a function') : invariant(false) : void 0;
  var handlerRef = useLatest(handler);
  useEffect(function () {
    var handleBeforeunload = function handleBeforeunload(event) {
      var returnValue = handlerRef.current == null ? void 0 : handlerRef.current(event); // Handle legacy `event.returnValue` property
      // https://developer.mozilla.org/en-US/docs/Web/API/Window/beforeunload_event

      if (typeof returnValue === 'string') {
        return event.returnValue = returnValue;
      } // Chrome doesn't support `event.preventDefault()` on `BeforeUnloadEvent`,
      // instead it requires `event.returnValue` to be set
      // https://developer.mozilla.org/en-US/docs/Web/API/WindowEventHandlers/onbeforeunload#browser_compatibility


      if (event.defaultPrevented) {
        return event.returnValue = '';
      }
    };

    window.addEventListener('beforeunload', handleBeforeunload);
    return function () {
      window.removeEventListener('beforeunload', handleBeforeunload);
    };
  }, []); // eslint-disable-line react-hooks/exhaustive-deps
};

var Beforeunload = function Beforeunload(_ref) {
  var _ref$children = _ref.children,
      children = _ref$children === void 0 ? null : _ref$children,
      onBeforeunload = _ref.onBeforeunload;
  useBeforeunload(onBeforeunload);
  return children;
};

Beforeunload.propTypes
/* remove-proptypes */
= process.env.NODE_ENV !== "production" ? {
  children: PropTypes.any,
  onBeforeunload: PropTypes.func.isRequired
} : {};

export { Beforeunload, useBeforeunload };
//# sourceMappingURL=index.esm.js.map
